﻿Type=StaticCode
Version=5.9
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'--------------------------------------------------------------------------------------------------------------------------------------
'   Static Code Module  
'--------------------------------------------------------------------------------------------------------------------------------------
Sub Process_Globals
	Type  TFileInfo(IsValid As Boolean, FullName As String, Drive As String, Path As String, FileName As String, Extension As String)

	'---------------------------------------------------------------------------------
	'  Flags used to control parsing - can be set globally or by SetWanted routine
	'---------------------------------------------------------------------------------
	Public  mWantDriveCollon		As Boolean	= True
	Public	mWantLastSlash			As Boolean	= True
	Public	mWantExtensionPeriod	As Boolean	= True
	
	Public  mLowerCaseAll			As Boolean  = True
End Sub


'------------------------------------------------------------------------------------------------------------------------
'  SetWanded take 3 parameters indicating should Drive Collon, LastPathSlash and FixExtensionPeriod be returned
'------------------------------------------------------------------------------------------------------------------------
Public  Sub SetWanted(DriveCollon As Boolean, LastPathSlash As Boolean, FileExtensionPeriod As Boolean)
			mWantDriveCollon 		= DriveCollon
			mWantLastSlash			= LastPathSlash
			mWantExtensionPeriod	= FileExtensionPeriod
End Sub

'------------------------------------------------------------------------------------------------------------------------
'  SetLowerCaseAll
'------------------------------------------------------------------------------------------------------------------------
Public  Sub SetLowerCaseAll(LowerCase As Boolean)
			mLowerCaseAll			= LowerCase
End Sub

'----------------------------------------------------------------------------------------------------------------------------
'  FileInfo take 1 parameter a string to a complete file path and parses into its individual parts
'			a TFileInfo type is returne.  Has the individual peiece as well as the original filename and a Valid check flag
'----------------------------------------------------------------------------------------------------------------------------
Public  Sub FileInfo(CompleteFilePath As String) As TFileInfo
			Dim FInfo As TFileInfo

			CompleteFilePath = CompleteFilePath.Trim

			If  mLowerCaseAll Then
				CompleteFilePath = CompleteFilePath.ToLowerCase
			End If
			
			FInfo.Initialize
			FInfo.FullName	= CompleteFilePath


			'--------------------------------------------------------------------
			'  If the CompletFilePath that was passed
			'		has a Zero length then nothing but just return the
			'		TFileInfo with the passed name in it (Valid set to false)
			'--------------------------------------------------------------------
			If  CompleteFilePath.Length = 0 Then Return FInfo
			
			
			'--------------------------------------------------------------------
			'  Used to change Offset based on if we want these returned or not
			'--------------------------------------------------------------------
			Dim IncludeCollon 			As Int 	= 0
			Dim IncludeSlash			As Int  = 0
			Dim IncludePeriod			As Int  = 0
			
			'--------------------------------------------------------------------
			'  Set DriveCollon offset
			'--------------------------------------------------------------------
			If  mWantDriveCollon 		Then 
				IncludeCollon = 1
			Else
				IncludeCollon = 0
			End If
			
			'--------------------------------------------------------------------
			'  Set LastSlash offset
			'--------------------------------------------------------------------
			If  mWantLastSlash			Then 
				IncludeSlash  =  1
			Else
				IncludeSlash  =  0
			End If
			
			'--------------------------------------------------------------------
			'  Set ExtensionPeriod offset
			'--------------------------------------------------------------------
			If  mWantExtensionPeriod	Then 
				IncludePeriod = 0
			Else
				IncludePeriod = 1
			End If


			'--------------------------------------------------------------------
			'  Fields to calc the offset distances
			'--------------------------------------------------------------------
			Dim DriveOffset	As Int
			Dim PathOffset 	As Int
			Dim ExtOffset	As Int

			'--------------------------------------------------------------------
			'  Get locations of Drive Collon, Last Slash and the Last Period
			'--------------------------------------------------------------------				
			DriveOffset = CompleteFilePath.IndexOf(":")
			PathOffset 	= CompleteFilePath.LastIndexOf("\")
			ExtOffset	= CompleteFilePath.LastIndexOf(".")

			'--------------------------------------------------------------------
			'  Get Extension with or without period
			'--------------------------------------------------------------------
			If  ExtOffset <> -1 	Then  FInfo.Extension = CompleteFilePath.SubString(ExtOffset + IncludePeriod)
				
			'--------------------------------------------------------------------
			'  Get Drive with or without collon
			'--------------------------------------------------------------------				
			If  DriveOffset <> -1 	Then	FInfo.Drive = CompleteFilePath.SubString2(0, (DriveOffset + IncludeCollon))
				
			'--------------------------------------------------------------------
			'  We could have just a Drive Collon and FileName like
			'		C:User.txt
			'--------------------------------------------------------------------				
			If  PathOffset <> -1 Then
				'----------------------------------------------------------------
				'  Have Path.  Pull it from the string
				'----------------------------------------------------------------
				If  DriveOffset <> -1 Then
					FInfo.Path = CompleteFilePath.SubString2((DriveOffset + 1), (PathOffset + IncludeSlash))
				Else
					FInfo.Path = CompleteFilePath.SubString2(0, (PathOffset + IncludeSlash))
				End If
					
				'----------------------------------------------------------------
				'  Get the FileName from the path without the extension
				'----------------------------------------------------------------	
				If  ExtOffset <> -1 Then
					Try
						FInfo.FileName = CompleteFilePath.SubString2(PathOffset+1, ExtOffset)
					Catch
						Log("Oops")
					End Try
				Else
					FInfo.FileName = CompleteFilePath.SubString(PathOffset+1)						
				End If
			Else
				'----------------------------------------------------------------
				'  Don't have path ?? Do we have a Drive
				'----------------------------------------------------------------
				If  DriveOffset <> -1 Then
					'------------------------------------------------------------
					'  Get the Filename 
					'------------------------------------------------------------
					If  ExtOffset <> -1 Then
						FInfo.FileName = CompleteFilePath.SubString2(DriveOffset+1, ExtOffset)
					Else
						FInfo.FileName = CompleteFilePath.SubString(DriveOffset+1)						
					End If										
				Else
					'--------------------------------------------------------------------
					'  No Path, No Drive just a filename (with or without an extension)
					'--------------------------------------------------------------------
					If  ExtOffset <> -1 Then
						FInfo.FileName = CompleteFilePath.SubString2(0, ExtOffset)
					Else
						FInfo.FileName = CompleteFilePath
					End If					
				End If
			End If
			
			'-----------------------------------------------------------------------------------------------------------------------
			'  If we have ANY of the individual parts I have to assume that everything is valid and set the returning type to Valid
			'     put them in order of most likely to have
			'-----------------------------------------------------------------------------------------------------------------------
			If  FInfo.FileName.Length <> 0 Or FInfo.Extension.Length <> 0 Or FInfo.Path.Length <> 0 Or FInfo.Drive.Length <> 0  Then
				FInfo.IsValid = True
			End If
			
			Return FInfo	
End Sub
